Index: cc/surfaces/framesink_manager.h |
diff --git a/cc/surfaces/framesink_manager.h b/cc/surfaces/framesink_manager.h |
index 087126c1fb28361da98709cafc236eda18a0bcbe..fa1b38dbfa6347de609914e4cf663d70ad7d72ff 100644 |
--- a/cc/surfaces/framesink_manager.h |
+++ b/cc/surfaces/framesink_manager.h |
@@ -18,7 +18,7 @@ |
namespace cc { |
class BeginFrameSource; |
-class SurfaceFactoryClient; |
+class CompositorFrameSinkSupport; |
namespace test { |
class CompositorFrameSinkSupportTest; |
@@ -35,20 +35,20 @@ class CC_SURFACES_EXPORT FrameSinkManager { |
// possibly because a renderer process has crashed. |
void InvalidateFrameSinkId(const FrameSinkId& frame_sink_id); |
// SurfaceFactoryClient, hierarchy, and BeginFrameSource can be registered |
// and unregistered in any order with respect to each other. |
// |
// This happens in practice, e.g. the relationship to between ui::Compositor / |
// DelegatedFrameHost is known before ui::Compositor has a surface/client). |
// However, DelegatedFrameHost can register itself as a client before its |
// relationship with the ui::Compositor is known. |
- // Associates a SurfaceFactoryClient with the frame_sink_id it uses. |
- // SurfaceFactoryClient and framesink allocators have a 1:1 mapping. |
- // Caller guarantees the client is alive between register/unregister. |
- void RegisterSurfaceFactoryClient(const FrameSinkId& frame_sink_id, |
- SurfaceFactoryClient* client); |
- void UnregisterSurfaceFactoryClient(const FrameSinkId& frame_sink_id); |
+ // Associates a CompositorFrameSinkSupport with the frame_sink_id it uses. |
+ // CompositorFrameSinkSupport and framesink allocators have a 1:1 mapping. |
+ // Caller guarantees |support| is alive between register/unregister. |
+ void RegisterCompositorFrameSinkSupport(const FrameSinkId& frame_sink_id, |
+ CompositorFrameSinkSupport* support); |
+ void UnregisterCompositorFrameSinkSupport(const FrameSinkId& frame_sink_id); |
// Associates a |source| with a particular framesink. That framesink and |
// any children of that framesink with valid clients can potentially use |
@@ -90,8 +90,9 @@ class CC_SURFACES_EXPORT FrameSinkManager { |
// considered satisfied. |
std::unordered_set<FrameSinkId, FrameSinkIdHash> valid_frame_sink_ids_; |
// Begin frame source routing. Both BeginFrameSource and SurfaceFactoryClient |
// pointers guaranteed alive by callers until unregistered. |
struct FrameSinkSourceMapping { |
FrameSinkSourceMapping(); |
FrameSinkSourceMapping(const FrameSinkSourceMapping& other); |
@@ -103,7 +104,7 @@ class CC_SURFACES_EXPORT FrameSinkManager { |
std::vector<FrameSinkId> children; |
}; |
- std::unordered_map<FrameSinkId, SurfaceFactoryClient*, FrameSinkIdHash> |
+ std::unordered_map<FrameSinkId, CompositorFrameSinkSupport*, FrameSinkIdHash> |
clients_; |
std::unordered_map<FrameSinkId, FrameSinkSourceMapping, FrameSinkIdHash> |
@@ -35,20 +35,20 @@ class CC_SURFACES_EXPORT FrameSinkManager { |
// possibly because a renderer process has crashed. |
void InvalidateFrameSinkId(const FrameSinkId& frame_sink_id); |
- // SurfaceFactoryClient, hierarchy, and BeginFrameSource can be registered |
- // and unregistered in any order with respect to each other. |
+ // CompositorFrameSinkSupport, hierarchy, and BeginFrameSource can be |
+ // registered and unregistered in any order with respect to each other. |
// |
// This happens in practice, e.g. the relationship to between ui::Compositor / |
@@ -90,8 +90,9 @@ class CC_SURFACES_EXPORT FrameSinkManager { |
// considered satisfied. |
std::unordered_set<FrameSinkId, FrameSinkIdHash> valid_frame_sink_ids_; |
- // Begin frame source routing. Both BeginFrameSource and SurfaceFactoryClient |
- // pointers guaranteed alive by callers until unregistered. |
+ // Begin frame source routing. Both BeginFrameSource and |
+ // CompositorFrameSinkSupport pointers guaranteed alive by callers until |
+ // unregistered. |
struct FrameSinkSourceMapping { |
FrameSinkSourceMapping(); |